/* TTMPTestPlat.h
 *
 * Declarations and definitions for test programs under Linux.
 *
 * Copyright (C) 2005-2006 TomTom BV <http://www.tomtom.com/>
 * Author 0: Dimitry Andric <dimitry.andric@tomtom.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2
 * as published by the Free Software Foundation.
 */

#ifndef INCLUDED_TTMPTESTPLAT_H
#define INCLUDED_TTMPTESTPLAT_H

#include <errno.h>
#include <signal.h>
#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include "TTMPPlat.h"

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define VER_MAJOR 1
#define VER_MINOR 1

#define TEST_ADDRESS "testsock"
//#define TEST_ADDRESS "127.0.0.1:8888"

/* Print the generic information that is available for all signals. */
static void sigaction_generic_info(int num, siginfo_t* info, void* context)
{
	static char sa_buf[512];
	snprintf(sa_buf, sizeof sa_buf,
		"#### RECEIVED SIGNAL %d [errno %d code %d], RESUMING.\n",
		num, info->si_errno, info->si_code);
	write(STDERR_FILENO, sa_buf, strlen(sa_buf));
	UNUSED_PARAM(context);
}

/* Wrapper to set up a signal action. */
static void setsigaction(int num, void (*handler)(int, struct siginfo *, void *))
{
	struct sigaction sa;
	memset(&sa, 0, sizeof sa);
	sa.sa_sigaction = handler;
	sigemptyset(&sa.sa_mask);
	sa.sa_flags = SA_SIGINFO;
	if (sigaction(num, &sa, NULL))
		fprintf(stderr, "%s: sigaction failed: %s\n", __FUNCTION__, strerror(errno));
}

static inline void signals_init(void)
{
	setsigaction(SIGHUP,  sigaction_generic_info);
	setsigaction(SIGINT,  sigaction_generic_info);
	setsigaction(SIGQUIT, sigaction_generic_info);
	setsigaction(SIGTERM, sigaction_generic_info);
}

static inline void sockets_init(void)
{
}

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* INCLUDED_TTMPTESTPLAT_H */

/* EOF */
