/* TTMPSock.h
 *
 * TTMPSocket declarations.
 *
 * Copyright (C) 2005-2006 TomTom BV <http://www.tomtom.com/>
 * Author 0: Dimitry Andric <dimitry.andric@tomtom.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2
 * as published by the Free Software Foundation.
 */

#ifndef INCLUDED_TTMPSOCK_H
#define INCLUDED_TTMPSOCK_H

#include "TTMP.h"
#include "TTMPPlat.h"

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define SOCKET_INVALID(_sock) ((_sock) == INVALID_SOCKET)
#define SOCKET_VALID(_sock)   ((_sock) != INVALID_SOCKET)

typedef struct sTTMPSocketAddress {
	int domain;
	TUint32 size;
	TTMPSockAddr addr;
} TTMPSocketAddress;

typedef struct sTTMPBuffer {
	TUint8 *data;
	TUint32 size;
	TUint32 ofs;
} TTMPBuffer;

int TTMPSocketAddressParse(cTTMPAddress addr, TTMPSocketAddress *sa);
int TTMPSocketCreate(TTMPSocket *sock, int domain);
int TTMPSocketDestroy(TTMPSocket sock);
int TTMPSocketNonBlocking(TTMPSocket sock);
int TTMPSocketSelect(TTMPSocket sock, fd_set *rset, fd_set *wset, fd_set *eset, TInt32 timeout);
int TTMPSocketConnectSync(TTMPSocket sock, const TTMPSocketAddress *sa);
int TTMPSocketConnect(TTMPSocket sock, const TTMPSocketAddress *sa, TInt32 timeout);
int TTMPSocketBind(TTMPSocket sock, const TTMPSocketAddress *sa);
int TTMPSocketUnbind(TTMPSocket sock, const TTMPSocketAddress *sa);
int TTMPSocketListen(TTMPSocket sock, int maxconn);
int TTMPSocketAcceptSync(TTMPSocket sock, TTMPSocket *newsock);
int TTMPSocketAccept(TTMPSocket sock, TTMPSocket *newsock, TInt32 timeout);
int TTMPSocketSendSync(TTMPSocket sock, const TUint8 *buf, TUint32 len, TUint32 *sent);
int TTMPSocketSend(TTMPSocket sock, const TUint8 *buf, TUint32 len, TUint32 *sent, TInt32 timeout);
int TTMPSocketSendBuffer(TTMPSocket sock, TTMPBuffer *buf, TInt32 timeout);
int TTMPSocketReceiveSync(TTMPSocket sock, TUint8 *buf, TUint32 len, TUint32 *received);
int TTMPSocketReceive(TTMPSocket sock, TUint8 *buf, TUint32 len, TUint32 *received, TInt32 timeout);
int TTMPSocketReceiveBuffer(TTMPSocket sock, TTMPBuffer *buf, TInt32 timeout);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* INCLUDED_TTMPSOCK_H */

/* EOF */
